@@ -12,12 +12,12 @@ def test_cli_version():
     assert f"v{virtue.__version__}" in result.stdout
 
 def test_cli_info():
-    result = runner.invoke(app, ["info"])
+    result = runner.invoke(app, ["env", "info"])
     assert result.exit_code == 0
     assert result.stdout != ""
 
 def test_cli_list():
-    result = runner.invoke(app, ["list"])
+    result = runner.invoke(app, ["env", "list"])
     assert result.exit_code == 0
     assert "Virtue Packages" in result.stdout
     assert "Python Package" in result.stdout
